SYNOPSIS
my $oidc = Browser::OIDC->new($url);
my $token_response = $oidc->get_token(%args);
my $id_token = $token_response->id_token;
DESCRIPTION
This represents a token as returned by Browser::OIDC-get_token>. It should always contain an ID token, and usually an access token as well.
METHODS
id_token
This returns the raw ID token. This should be JWT formatted and is not validated.
access_token
This returns the raw access token.
expires_in
The amount of time from fetching until the access token expires, in seconds.
token_type
The type of the token. This will usually be 'bearer'.